#! /usr/bin/env python
#
# Opens a new tab in epiphany when double clicking a tab or the empty tab
# space
#
# Version: 0.1
#
# Copyright (C) 2007 Meir Kriheli <meir@mksoft.co.il>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the:
#
# Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston,
# MA 02111-1307  USA
#
# vim: set ts=4 sw=4 et:

import gtk
import epiphany

# default url for the new tab
DEFAULT_URL = 'about:blank'

# new tab options for Epiphany, just to make the
# code readable later on
NEW_TAB_OPTS = \
    epiphany.NEW_TAB_IN_EXISTING_WINDOW | \
    epiphany.NEW_TAB_APPEND_LAST | \
    epiphany.NEW_TAB_OPEN_PAGE

def button_pressed(object, event, window):
    "Check if it's a double click, if so open new tab"

    if event.button == 1 and event.type == gtk.gdk._2BUTTON_PRESS:
        e_shell = epiphany.ephy_shell_get_default()
        tab = window.get_active_tab()
        notebook = window.get_notebook()
        
        # Create a new tab
        new_tab = e_shell.new_tab( window, tab, DEFAULT_URL, NEW_TAB_OPTS )

        # Give it focus
        notebook.set_current_page( notebook.page_num(new_tab) )
        return True
    else:
        return False

def attach_window(window):
    "Called upon loading the extension"

    notebook = window.get_notebook()
    notebook.newtab_signal_handler = notebook.connect('button-press-event', button_pressed , window)

def detach_window(window):
    "Called upon unloading the extension"

    notebook = window.get_notebook()
    if notebook.newtab_signal_handler:
        notebook.disconnect(notebook.newtab_signal_handler)
        del notebook.newtab_signal_handler

